@@ -16,7 +16,7 @@ def image():
 def test_image_ndarray_to_b64data(image):
     b64data = _json.image_ndarray_to_b64data(image)
     assert isinstance(b64data, str)
-    assert len(b64data) == 204
+    assert len(b64data) in [204, 208]  # pillow version differences v10 vs v12
 
 
 def test_image_b64data_to_ndarray(image):
