@@ -1,15 +1,17 @@
 from typing import Optional
 from typing import Type
+from typing import cast
 
 import numpy as np
 import onnxruntime
+from numpy.typing import NDArray
 
 from . import _models
 from . import types
 
 running_model: Optional[types.Model] = None
 
-registered_model_types: list[Type] = [
+registered_model_types: list[Type[types.Model]] = [
     _models.EfficientSam10m,
     _models.EfficientSam30m,
     _models.Sam100m,
@@ -17,13 +19,14 @@ registered_model_types: list[Type] = [
     _models.Sam2Large,
     _models.Sam2Small,
     _models.Sam2Tiny,
+    _models.Sam3,
     _models.Sam300m,
     _models.Sam600m,
     _models.YoloWorldXL,
 ]
 
 
-def get_model_type_by_name(name: str) -> Type:
+def get_model_type_by_name(name: str) -> Type[types.Model]:
     model_name: str
     if ":" in name:
         model_name = name
@@ -56,12 +59,14 @@ _non_maximum_suppression_inference_session: Optional[
 
 
 def non_maximum_suppression(
-    boxes: np.ndarray,
-    scores: np.ndarray,
+    boxes: NDArray[np.floating],
+    scores: NDArray[np.floating],
     iou_threshold: float,
     score_threshold: float,
     max_num_detections: int,
-) -> tuple[np.ndarray, np.ndarray, np.ndarray]:
+) -> tuple[
+    NDArray[np.floating], NDArray[np.floating], NDArray[np.int64], NDArray[np.int64]
+]:
     global _non_maximum_suppression_inference_session
     if _non_maximum_suppression_inference_session is None:
         blob = types.Blob(
@@ -74,7 +79,7 @@ def non_maximum_suppression(
         )
     inference_session = _non_maximum_suppression_inference_session
 
-    selected_indices = inference_session.run(
+    outputs = inference_session.run(
         output_names=["selected_indices"],
         input_feed={
             "boxes": boxes[None, :, :],
@@ -85,16 +90,19 @@ def non_maximum_suppression(
             "iou_threshold": np.array([iou_threshold], dtype=np.float32),
             "score_threshold": np.array([score_threshold], dtype=np.float32),
         },
-    )[0]
+    )
+    selected_indices = cast(NDArray[np.int64], outputs[0])
     labels = selected_indices[:, 1]
     box_indices = selected_indices[:, 2]
     boxes = boxes[box_indices]
     scores = scores[box_indices, labels]
+    indices = box_indices
 
     if len(boxes) > max_num_detections:
         keep_indices = np.argsort(scores)[-max_num_detections:]
         boxes = boxes[keep_indices]
         scores = scores[keep_indices]
         labels = labels[keep_indices]
+        indices = indices[keep_indices]
 
-    return boxes, scores, labels
+    return boxes, scores, labels, indices
